==> lxqt-config_0.17.1.orig.tar.xz: lxqt-config-0.17.1/lxqt-config-locale/translations/lxqt-config-locale_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../localeconfig.ui" line="47"/>
        <source>Re&amp;gion:</source>
        <translation>Регі&amp;он:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="76"/>
        <source>De&amp;tailed Settings</source>
        <translation>Де&amp;тальні налаштування</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="83"/>
        <source>&amp;Numbers:</source>
        <translation>&amp;Числа:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="112"/>
        <source>&amp;Time:</source>
        <translation>&amp;Час:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="141"/>
        <source>Currenc&amp;y:</source>
        <translation>В&amp;алюта:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="170"/>
        <source>Measurement &amp;Units:</source>
        <translation>О&amp;диниці вимірювання:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="199"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation>Розб&amp;ір і сортування:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="238"/>
        <source>&lt;b&gt;Examples&lt;/b&gt;</source>
        <translation>&lt;b&gt;Приклади&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="248"/>
        <source>Numbers:</source>
        <translation>Числа:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="268"/>
        <source>Time:</source>
        <translation>Час:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="288"/>
        <source>Currency:</source>
        <translation>Валюта:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="308"/>
        <source>Measurement Units:</source>
        <translation>Одиниці виміру:</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="127"/>
        <source>No change</source>
        <translation>Без змін</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="316"/>
        <source>Format Settings Changed</source>
        <translation>Налаштування формату змінено</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="317"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation>Хочете зберегти зміни? Вони наберуть чинності за наступного входу в систему.</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="438"/>
        <source>Imperial UK</source>
        <translation>Імперські UK</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="442"/>
        <source>Imperial US</source>
        <translation>Імперські US</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="446"/>
        <source>Metric</source>
        <translation>Метричні</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>LXQt Locale Configuration</source>
        <translation>Налаштування локалі LXQT</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>Locale Settings</source>
        <translation>Налаштування локалі</translation>
    </message>
</context>
</TS>

==> lxqt-config_1.4.0.orig.tar.xz: lxqt-config-1.4.0/lxqt-config-locale/translations/lxqt-config-locale_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../localeconfig.ui" line="31"/>
        <source>Re&amp;gion:</source>
        <translation>Регі&amp;он:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="60"/>
        <source>De&amp;tailed Settings</source>
        <translation>Де&amp;тальні налаштування</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="78"/>
        <source>&amp;Numbers:</source>
        <translation>&amp;Числа:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="107"/>
        <source>&amp;Time:</source>
        <translation>&amp;Час:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="136"/>
        <source>Currenc&amp;y:</source>
        <translation>В&amp;алюта:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="165"/>
        <source>Measurement &amp;Units:</source>
        <translation>О&amp;диниці вимірювання:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="194"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation>Розб&amp;ір і сортування:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="226"/>
        <source>Examples</source>
        <translation>Приклади</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="238"/>
        <source>Numbers:</source>
        <translation>Числа:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="258"/>
        <source>Time:</source>
        <translation>Час:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="278"/>
        <source>Currency:</source>
        <translation>Валюта:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="298"/>
        <source>Measurement Units:</source>
        <translation>Одиниці виміру:</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="126"/>
        <source>No change</source>
        <translation>Без змін</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="313"/>
        <source>Format Settings Changed</source>
        <translation>Налаштування формату змінено</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="314"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation>Хочете зберегти зміни? Вони наберуть чинності за наступного входу в систему.</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="417"/>
        <source>Imperial UK</source>
        <translation>Імперські UK</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="421"/>
        <source>Imperial US</source>
        <translation>Імперські US</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="425"/>
        <source>Metric</source>
        <translation>Метричні</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>LXQt Locale Configuration</source>
        <translation>Налаштування локалі LXQT</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>Locale Settings</source>
        <translation>Налаштування локалі</translation>
    </message>
</context>
</TS>
